@echo OFF
cls
setlocal enabledelayedexpansion

rem <PROGRAM-HEADER>
echo **************************************************
echo *
echo * PRTG backup script
echo *
echo **************************************************
echo.
echo --------------------------------------------------------------------------------
rem: Informations :
rem         Author   : Vincent Duvernet
rem         Company  : Nolmë Informatique
rem         Web site : http://www.nolme.com
rem 
rem: Version :
rem         Creation Date     : 2021/03/23
rem         Last modification : 2021/03/23
rem 
rem: Pre-required application(s) :
rem         Microsoft .NET framework 4.0
rem         Nolmë Informatique Command Line Tools 4.x
rem 
rem: Notes :
rem         This script use a dedicated local version of 7-Zip and Microsoft Robocopy.
rem			By default, this script must be stored in c:\Backup.
rem			You can adjust PRTG & tools location by modifying variables in the <INIT> section.
rem 
rem: Sources :
rem 		https://kb.paessler.com/en/topic/463-how-and-where-does-prtg-store-its-data
rem 		https://kb.paessler.com/en/topic/523-how-do-i-back-up-all-data-and-configuration-of-my-prtg-installation
rem
rem ************************************************************************************************************************
rem </PROGRAM-HEADER>

rem <INIT>
	set g_strBatchPath=%~dp0
	set g_strRoboCopyFullPath=c:\Backup\robocopy.exe
	set g_strRoboLogsFullPath=c:\Backup\robocopy.txt
	set g_str7ZipFullPath=C:\Backup\7z\7za.exe
	set g_strDstBackupFullPath=c:\Backup\PRTG
	set g_strSrcPrtgProgramData=%ProgramData%\Paessler
	set g_strSrcPrtgAppX64=!programfiles!\PRTG Network Monitor
	set g_strSrcPrtgAppX86=!programfiles(x86)!\PRTG Network Monitor
rem </INIT>

rem <MAIN>
	rem show start time
	echo Current date/time is %DATE% %TIME%

	echo Backup Registry keys
	reg save "HKLM\SOFTWARE\Paessler\PRTG Network Monitor" "!g_strDstBackupFullPath!\Registry_x86.reg" /y /reg:32
	reg save "HKLM\SOFTWARE\Paessler\PRTG Network Monitor" "!g_strDstBackupFullPath!\Registry_x64.reg" /y /reg:64
	
	echo Stop PRTG services

	rem this service is part of UVExplorer only
	NET STOP "PRTG UVexplorer Service"

	rem stop Paessler services
	NET STOP "PRTG Probe Service"
	NET STOP "PRTG Core Server Service"

	rem echo Copy PRTG datas
	rem "!g_strRoboCopyFullPath!" "!g_strSrcPrtgProgramData!"  "!g_strDstBackupFullPath!\Paessler"  /R:0 /W:0 /FFT /MIR /NP /LOG+:!g_strRoboLogsFullPath!

	rem echo Copy PRTG application
	rem "!g_strRoboCopyFullPath!" "!g_strSrcPrtgAppX86!"  "!g_strDstBackupFullPath!\Program files (x86)\PRTG Network Monitor"  /R:0 /W:0 /FFT /MIR /NP /LOG+:!g_strRoboLogsFullPath!
	rem "!g_strRoboCopyFullPath!" "!g_strSrcPrtgAppX64!"  "!g_strDstBackupFullPath!\Program files\PRTG Network Monitor"  /R:0 /W:0 /FFT /MIR /NP /LOG+:!g_strRoboLogsFullPath!

	echo Compress PRTG application
	"!g_str7ZipFullPath!" a -t7z -r "!g_strDstBackupFullPath!\PrtgProgramFiles_x86.7z"   "!g_strSrcPrtgAppX86!\*.*"
	"!g_str7ZipFullPath!" a -t7z -r "!g_strDstBackupFullPath!\PrtgProgramFiles_x64.7z"   "!g_strSrcPrtgAppX64!\*.*"

	echo Compress PRTG datas
	"!g_str7ZipFullPath!" a -t7z -r "!g_strDstBackupFullPath!\PrtgProgramData.7z"   "!g_strSrcPrtgProgramData!\*.*"

	echo Restart services
	NET START "PRTG Core Server Service"
	NET START "PRTG Probe Service"

	NET START "PRTG UVexplorer Service"

	rem show end time
	echo Current date/time is %DATE% %TIME%
	echo End of script.
rem </MAIN>